==> PurpleSk%201.4.jar: me/pugabear/PurpleSk/Effects/EffMute.java <==
package me.pugabear.PurpleSk.Effects;

import org.bukkit.Bukkit;
import org.bukkit.event.Event;
import org.bukkit.plugin.Plugin;

import com.cnaude.purpleirc.PurpleIRC;
import com.cnaude.purpleirc.ext.org.pircbotx.Channel;
import com.cnaude.purpleirc.ext.org.pircbotx.User;

import ch.njol.skript.Skript;
import ch.njol.skript.lang.Effect;
import ch.njol.skript.lang.Expression;
import ch.njol.skript.lang.SkriptParser.ParseResult;
import ch.njol.util.Kleenean;
import me.pugabear.PurpleSk.PurpleSk;

public class EffMute extends Effect {
	
	public static String syntax = "[irc] mute [user] %string% in [channel] %string% with bot %string%";
	
	private Expression<String> bot;
	private Expression<String> channel;
	private Expression<String> user;
	
	@SuppressWarnings("unchecked")
	@Override
	public boolean init(Expression<?>[] e, int arg1, Kleenean arg2, ParseResult arg3) {
		user = (Expression<String>) e[0];
		channel = (Expression<String>) e[1];
		bot = (Expression<String>) e[2];
		return true;
	}
	
	@Override
	public String toString(Event paramEvent, boolean paramBoolean) {
		return syntax;
	}
	
	@Override
	protected void execute(Event e) {
		Plugin plugin = Bukkit.getPluginManager().getPlugin("PurpleIRC"); 
		PurpleIRC pirc = (PurpleIRC) plugin;
		String b = bot.getSingle(e);
		String c = channel.getSingle(e);
		String u = user.getSingle(e);
		if (!c.contains("#")) {
			c = "#" + c;
		}
		if (pirc.ircBots.containsKey(b) && b != null && c != null && u != null) {
            String mask = u;
            Channel channel = pirc.ircBots.get(b).getChannel(c);
            if (channel != null) {
                for (User user : channel.getUsers()) {
                    if (user.getNick().equalsIgnoreCase(u)) {
                        mask = "*!*" + user.getLogin() + "@" + user.getHostmask();
                    }
                }
            }
            if (mask.split("[\\!\\@]", 3).length == 3) {
                pirc.ircBots.get(b).mute(c, PurpleSk.pluginInstance.getServer().getConsoleSender(), mask);
            } else {
                Skript.error("Invalid user or mask: " + mask);
            }
		} else {
			Skript.error("Bot \"" + b + "\" not found or arguments null");
		}
	}
	

	public static void register() {
		Skript.registerEffect(EffMute.class, syntax);
	}
}

==> PurpleSk%201.6.jar: me/pugabear/PurpleSk/Effects/EffMute.java <==
package me.pugabear.PurpleSk.Effects;

import org.bukkit.Bukkit;
import org.bukkit.event.Event;
import org.bukkit.plugin.Plugin;

import com.cnaude.purpleirc.PurpleIRC;
import com.cnaude.purpleirc.ext.org.pircbotx.Channel;
import com.cnaude.purpleirc.ext.org.pircbotx.User;

import ch.njol.skript.Skript;
import ch.njol.skript.lang.Effect;
import ch.njol.skript.lang.Expression;
import ch.njol.skript.lang.SkriptParser.ParseResult;
import ch.njol.util.Kleenean;
import me.pugabear.PurpleSk.PurpleSk;

public class EffMute extends Effect {
	
	public static String syntax = "[irc] mute [user] %string% in [channel] %string% with bot %string%";
	
	private Expression<String> bot;
	private Expression<String> channel;
	private Expression<String> user;
	
	@SuppressWarnings("unchecked")
	@Override
	public boolean init(Expression<?>[] e, int arg1, Kleenean arg2, ParseResult arg3) {
		user = (Expression<String>) e[0];
		channel = (Expression<String>) e[1];
		bot = (Expression<String>) e[2];
		return true;
	}
	
	@Override
	public String toString(Event paramEvent, boolean paramBoolean) {
		return syntax;
	}
	
	@Override
	protected void execute(Event e) {
		Plugin plugin = Bukkit.getPluginManager().getPlugin("PurpleIRC"); 
		PurpleIRC pirc = (PurpleIRC) plugin;
		String b = bot.getSingle(e);
		String c = channel.getSingle(e);
		String u = user.getSingle(e);
		if (!c.contains("#")) {
			c = "#" + c;
		}
		if (pirc.ircBots.containsKey(b) && b != null && c != null && u != null) {
            String mask = u;
            Channel channel = pirc.ircBots.get(b).getChannel(c);
            if (channel != null) {
                for (User user : channel.getUsers()) {
                    if (user.getNick().equalsIgnoreCase(u)) {
                        mask = "*!*" + user.getLogin() + "@" + user.getHostmask();
                    }
                }
            }
            if (mask.split("[\\!\\@]", 3).length == 3) {
                pirc.ircBots.get(b).mute(c, PurpleSk.getInstance().getServer().getConsoleSender(), mask);
            } else {
                Skript.error("Invalid user or mask: " + mask);
            }
		} else {
			Skript.error("Bot \"" + b + "\" not found or arguments null");
		}
	}

	static {
		Skript.registerEffect(EffMute.class, syntax);
	}
}
